###################################################################################################
## Title: Bead quantification analysis script                                                    ##
## Project: Comparison Study                                                                     ##
## Version: 20190605                                                                             ##
## Author: Jaco Botha                                                                            ##
##                                                                                               ##
## Description:                                                                                  ##
## Script for analysing and plotting bead quantification data from three different flow cytome-  ##
## try platforms.                                                                                ##
###################################################################################################

#####
## Loading libraries for analysis and plotting.
#####

library(xlsx) ## for reading .xls and .xlsx files generated by FlowJo and IDEAS.
library(reshape2) ## for reshaping data from wide to long format.
library(ggplot2) ## for plotting data.


#####
## Support function for summarising data.
#####

#+++++++++++++++++++++++++
# Function to calculate the mean and the standard deviation
# for each group
#+++++++++++++++++++++++++
# data : a data frame
# varname : the name of a column containing the variable
#to be summariezed
# groupnames : vector of column names to be used as
# grouping variables
data_summary <- function(data, varname, groupnames){
  require(plyr)
  summary_func <- function(x, col){
    c(mean = mean(x[[col]], na.rm=TRUE),
      sd = sd(x[[col]], na.rm=TRUE))
  }
  data_sum<-ddply(data, groupnames, .fun=summary_func,
                  varname)
  data_sum <- rename(data_sum, c("mean" = varname))
  return(data_sum)
}


setwd("F:/ComparisonStudy/Results")


#####
## Part 1: Read data into memory.
#####

allFCMBeads<-read.xlsx(file = "./20190411_AllFCM_Beads.xlsx",sheetIndex = 1,header = T)

## Convert data to long format by flow cytometer.
allFCMBeads_Long<-melt(allFCMBeads,id.vars = "FCM")

## Conversion of bead concentration to numeric value for summarising.
allFCMBeads_Long$value<-as.numeric(allFCMBeads_Long$value)

## Summary (mean and SD) of data by FCM platform and bead population.
allFCMBeads_LongSummary<-data_summary(allFCMBeads_Long,varname = "value",
                                      groupnames = c("FCM","variable"))
allFCMBeads_LongSummary$CV<-allFCMBeads_LongSummary$sd/allFCMBeads_LongSummary$value*100

## Statistical analysis
pval_Beads<-list()

#Ps110nm
pval_Beads$Ps110nm<-pairwise.wilcox.test(x = allFCMBeads_Long$value[allFCMBeads_Long$variable=="Ps110nm"&allFCMBeads_Long$FCM!="AriaIII_SSC"],
                                         g = allFCMBeads_Long$FCM[allFCMBeads_Long$variable=="Ps110nm"&allFCMBeads_Long$FCM!="AriaIII_SSC"],
                                         paired = F, p.adjust.method = "holm")

#Ps280nm
pval_Beads$Ps280nm<-pairwise.wilcox.test(x = allFCMBeads_Long$value[allFCMBeads_Long$variable=="Ps280nm"&allFCMBeads_Long$FCM!="AriaIII_FL"],
                                         g = allFCMBeads_Long$FCM[allFCMBeads_Long$variable=="Ps280nm"&allFCMBeads_Long$FCM!="AriaIII_FL"],
                                         paired = F, p.adjust.method = "holm")

#Ps500nm
pval_Beads$Ps500nm<-pairwise.wilcox.test(x = allFCMBeads_Long$value[allFCMBeads_Long$variable=="Ps500nm"&allFCMBeads_Long$FCM!="AriaIII_SSC"],
                                         g = allFCMBeads_Long$FCM[allFCMBeads_Long$variable=="Ps500nm"&allFCMBeads_Long$FCM!="AriaIII_SSC"],
                                         paired = F, p.adjust.method = "holm")

#Si100nm
pval_Beads$Si100nm<-pairwise.wilcox.test(x = allFCMBeads_Long$value[allFCMBeads_Long$variable=="Si100nm"&!(allFCMBeads_Long$FCM=="AriaIII_SSC"|allFCMBeads_Long$FCM=="AriaIII_FL"|allFCMBeads_Long$FCM=="CellStream")],
                                         g = allFCMBeads_Long$FCM[allFCMBeads_Long$variable=="Si100nm"&!(allFCMBeads_Long$FCM=="AriaIII_SSC"|allFCMBeads_Long$FCM=="AriaIII_FL"|allFCMBeads_Long$FCM=="CellStream")],
                                         paired = F, p.adjust.method = "holm")

#Si180nm
pval_Beads$Si180nm<-pairwise.wilcox.test(x = allFCMBeads_Long$value[allFCMBeads_Long$variable=="Si180nm"&!(allFCMBeads_Long$FCM=="AriaIII_SSC"|allFCMBeads_Long$FCM=="AriaIII_FL"|allFCMBeads_Long$FCM=="CellStream")],
                                         g = allFCMBeads_Long$FCM[allFCMBeads_Long$variable=="Si180nm"&!(allFCMBeads_Long$FCM=="AriaIII_SSC"|allFCMBeads_Long$FCM=="AriaIII_FL"|allFCMBeads_Long$FCM=="CellStream")],
                                         paired = F, p.adjust.method = "holm")

#Si240nm
pval_Beads$Si240nm<-pairwise.wilcox.test(x = allFCMBeads_Long$value[allFCMBeads_Long$variable=="Si240nm"&!(allFCMBeads_Long$FCM=="AriaIII_SSC"|allFCMBeads_Long$FCM=="AriaIII_FL")],
                                         g = allFCMBeads_Long$FCM[allFCMBeads_Long$variable=="Si240nm"&!(allFCMBeads_Long$FCM=="AriaIII_SSC"|allFCMBeads_Long$FCM=="AriaIII_FL")],
                                         paired = F, p.adjust.method = "holm")

#Si300nm
pval_Beads$Si300nm<-pairwise.wilcox.test(x = allFCMBeads_Long$value[allFCMBeads_Long$variable=="Si300nm"&allFCMBeads_Long$FCM!="AriaIII_FL"],
                                         g = allFCMBeads_Long$FCM[allFCMBeads_Long$variable=="Si300nm"&allFCMBeads_Long$FCM!="AriaIII_FL"],
                                         paired = F, p.adjust.method = "holm")

#Si590nm
pval_Beads$Si590nm<-pairwise.wilcox.test(x = allFCMBeads_Long$value[allFCMBeads_Long$variable=="Si590nm"&allFCMBeads_Long$FCM!="AriaIII_FL"],
                                         g = allFCMBeads_Long$FCM[allFCMBeads_Long$variable=="Si590nm"&allFCMBeads_Long$FCM!="AriaIII_FL"],
                                         paired = F, p.adjust.method = "holm")

#Si880nm
pval_Beads$Si880nm<-pairwise.wilcox.test(x = allFCMBeads_Long$value[allFCMBeads_Long$variable=="Si880nm"&allFCMBeads_Long$FCM!="AriaIII_FL"],
                                         g = allFCMBeads_Long$FCM[allFCMBeads_Long$variable=="Si880nm"&allFCMBeads_Long$FCM!="AriaIII_FL"],
                                         paired = F, p.adjust.method = "holm")

#Si1300nm
pval_Beads$Si1300nm<-pairwise.wilcox.test(x = allFCMBeads_Long$value[allFCMBeads_Long$variable=="Si1300nm"&allFCMBeads_Long$FCM!="AriaIII_FL"],
                                          g = allFCMBeads_Long$FCM[allFCMBeads_Long$variable=="Si1300nm"&allFCMBeads_Long$FCM!="AriaIII_FL"],
                                          paired = F, p.adjust.method = "holm")


#####
## Part 2: Setting up plotting parameters.
#####

## Theme
th<-theme(axis.title = element_text(size=12,vjust=0),
          #axis.title.y=element_text(margin=margin(t=0,r=20,b=0,l=0)),
          axis.text = element_text(size=10,colour = "black"),
          axis.text.x=element_blank(),
          plot.title = element_text(size=14,face = "bold"),
          strip.text = element_text(size=12,vjust=0,face = "bold"),
          strip.background = element_blank(),
          axis.ticks.x = element_blank(),
          legend.position = "none")

## Colours for grouping FCM platforms.
fcmColours<-c("#E7B800", "#2E9FDF", "#FC4E07","#00E796")
notCellStream<-allFCMBeads_LongSummary$FCM!="CellStream"

## Plot 1: Ps110nm
Ps110nm_conc<-ggplot(data=allFCMBeads_LongSummary[allFCMBeads_LongSummary$variable=="Ps110nm"&allFCMBeads_LongSummary$FCM!="AriaIII_SSC"&notCellStream,],
                     aes(x=FCM,y=value/1000,fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  geom_errorbar(aes(ymax=(value+sd)/1000,ymin=(value-sd)/1000),size=0.8,width=0.25)+
  # Layout:
  labs(x="",y=expression(atop("Concentration",paste("[x ",10^3," Events/L]",sep=""))),title = "110 nm")+
  scale_x_discrete(limits=c("AriaIII_FL","Apogee","ISXII"),
                   labels= c("","","",""))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","AriaIII_FL","ISXII"))+
  theme_classic()+th

# Saving plot as .eps
Ps110nm_conc_grob<-ggplotGrob(Ps110nm_conc)
Ps110nm_conc_grob$respect=T
ggsave(filename = "Ps110nm_conc.pdf",plot=Ps110nm_conc_grob,device = "pdf",height = 45, units = "mm")

## Plot 2: Ps280nm
Ps280nm_conc<-ggplot(data=allFCMBeads_LongSummary[allFCMBeads_LongSummary$variable=="Ps280nm"&allFCMBeads_LongSummary$FCM!="AriaIII_FL"&notCellStream,],
                     aes(x=FCM,y=value,fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  geom_errorbar(aes(ymax=value+sd,ymin=value-sd),size=0.8,width=0.25)+
  # Layout:
  labs(x="",y="Concentration\n[Events/L",title = "280 nm")+
  scale_x_discrete(limits=c("AriaIII_SSC","Apogee","ISXII"),
                   labels= c("","","",""))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","AriaIII_SSC","ISXII"))+
  theme_classic()+th

# Saving plot as .eps
Ps280nm_conc_grob<-ggplotGrob(Ps280nm_conc)
Ps280nm_conc_grob$respect=T
ggsave(filename = "Ps280nm_conc.pdf",plot=Ps280nm_conc_grob,device = "pdf",height = 45, units = "mm")

## Plot 3: Ps500nm
Ps500nm_conc<-ggplot(data=allFCMBeads_LongSummary[allFCMBeads_LongSummary$variable=="Ps500nm"&allFCMBeads_LongSummary$FCM!="AriaIII_SSC"&notCellStream,],
                     aes(x=FCM,y=value,fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  geom_errorbar(aes(ymax=value+sd,ymin=value-sd),size=0.8,width=0.25)+
  # Layout:
  labs(x="",y="Concentration\n[Events/L]",title = "500 nm")+
  scale_x_discrete(limits=c("AriaIII_FL","Apogee","ISXII"))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","AriaIII_FL","ISXII"))+
  theme_classic()+th

# Saving plot as .eps
Ps500nm_conc_grob<-ggplotGrob(Ps500nm_conc)
Ps500nm_conc_grob$respect=T
ggsave(filename = "Ps500nm_conc.pdf",plot=Ps500nm_conc_grob,device = "pdf",height = 45, units = "mm")

## Plot 4: Si100nm
Si100nm_conc<-ggplot(data=allFCMBeads_LongSummary[allFCMBeads_LongSummary$variable=="Si100nm"&allFCMBeads_LongSummary$FCM!="AriaIII_FL"&notCellStream,],
                     aes(x=FCM,y=value/1000,fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  geom_errorbar(aes(ymax=(value+sd)/1000,ymin=(value-sd)/1000),size=0.8,width=0.25)+
  # Layout:
  labs(x="",y=expression(atop("Concentration",paste("[x ",10^3," Events/L]",sep=""))),title = "100 nm")+
  scale_x_discrete(limits=c("AriaIII_SSC","Apogee","ISXII"))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","AriaIII_SSC","ISXII"))+
  theme_classic()+th

# Saving plot as .eps
Si100nm_conc_grob<-ggplotGrob(Si100nm_conc)
Si100nm_conc_grob$respect=T
ggsave(filename = "Si100nm_conc.pdf",plot=Si100nm_conc_grob,device = "pdf",height = 45, units = "mm")

## Plot 5: Si180nm
Si180nm_conc<-ggplot(data=allFCMBeads_LongSummary[allFCMBeads_LongSummary$variable=="Si180nm"&allFCMBeads_LongSummary$FCM!="AriaIII_FL"&notCellStream,],
                     aes(x=FCM,y=value/1000,fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  geom_errorbar(aes(ymax=(value+sd)/1000,ymin=(value-sd)/1000),size=0.8,width=0.25)+
  # Layout:
  labs(x="",y=expression(atop("Concentration",paste("[x ",10^3," Events/L]",sep=""))),title = "180 nm")+
  scale_x_discrete(limits=c("AriaIII_SSC","Apogee","ISXII"))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","AriaIII_SSC","ISXII"))+
  theme_classic()+th

# Saving plot as .eps
Si180nm_conc_grob<-ggplotGrob(Si180nm_conc)
Si180nm_conc_grob$respect=T
ggsave(filename = "Si180nm_conc.pdf",plot=Si180nm_conc_grob,device = "pdf",height = 45, units = "mm")

## Plot 6: Si240nm
Si240nm_conc<-ggplot(data=allFCMBeads_LongSummary[allFCMBeads_LongSummary$variable=="Si240nm"&allFCMBeads_LongSummary$FCM!="AriaIII_FL"&notCellStream,],
                     aes(x=FCM,y=value,fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  geom_errorbar(aes(ymax=value+sd,ymin=value-sd),size=0.8,width=0.25)+
  # Layout:
  labs(x="",y="Concentration\n[Events/L]",title = "240 nm")+
  scale_x_discrete(limits=c("AriaIII_SSC","Apogee","ISXII"))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","AriaIII_SSC","ISXII"))+
  theme_classic()+th

# Saving plot as .eps
Si240nm_conc_grob<-ggplotGrob(Si240nm_conc)
Si240nm_conc_grob$respect=T
ggsave(filename = "Si240nm_conc.pdf",plot=Si240nm_conc_grob,device = "pdf",height = 45, units = "mm")

## Plot 7: Si300nm
Si300nm_conc<-ggplot(data=allFCMBeads_LongSummary[allFCMBeads_LongSummary$variable=="Si300nm"&allFCMBeads_LongSummary$FCM!="AriaIII_FL"&notCellStream,],
                     aes(x=FCM,y=value,fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  geom_errorbar(aes(ymax=value+sd,ymin=value-sd),size=0.8,width=0.25)+
  # Layout:
  labs(x="",y="Concentration\n[Events/L]",title = "300 nm")+
  scale_x_discrete(limits=c("AriaIII_SSC","Apogee","ISXII"))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","AriaIII_SSC","ISXII"))+
  theme_classic()+th

# Saving plot as .eps
Si300nm_conc_grob<-ggplotGrob(Si300nm_conc)
Si300nm_conc_grob$respect=T
ggsave(filename = "Si300nm_conc.pdf",plot=Si300nm_conc_grob,device = "pdf",height = 45, units = "mm")

## Plot 8: Si590nm
Si590nm_conc<-ggplot(data=allFCMBeads_LongSummary[allFCMBeads_LongSummary$variable=="Si590nm"&allFCMBeads_LongSummary$FCM!="AriaIII_FL"&notCellStream,],
                     aes(x=FCM,y=value,fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  geom_errorbar(aes(ymax=value+sd,ymin=value-sd),size=0.8,width=0.25)+
  # Layout:
  labs(x="",y="Concentration\n[Events/L]",title = "590 nm")+
  scale_x_discrete(limits=c("AriaIII_SSC","Apogee","ISXII"))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","AriaIII_SSC","ISXII"))+
  theme_classic()+th

# Saving plot as .eps
Si590nm_conc_grob<-ggplotGrob(Si590nm_conc)
Si590nm_conc_grob$respect=T
ggsave(filename = "Si590nm_conc.pdf",plot=Si590nm_conc_grob,device = "pdf",height = 45, units = "mm")

## Plot 9: Si880nm
Si880nm_conc<-ggplot(data=allFCMBeads_LongSummary[allFCMBeads_LongSummary$variable=="Si880nm"&allFCMBeads_LongSummary$FCM!="AriaIII_FL"&notCellStream,],
                     aes(x=FCM,y=value,fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  geom_errorbar(aes(ymax=value+sd,ymin=value-sd),size=0.8,width=0.25)+
  # Layout:
  labs(x="",y="Concentration\n[Events/L]",title = "880 nm")+
  scale_x_discrete(limits=c("AriaIII_SSC","Apogee","ISXII"))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","AriaIII_SSC","ISXII"))+
  theme_classic()+th

# Saving plot as .eps
Si880nm_conc_grob<-ggplotGrob(Si880nm_conc)
Si880nm_conc_grob$respect=T
ggsave(filename = "Si880nm_conc.pdf",plot=Si880nm_conc_grob,device = "pdf",height = 45, units = "mm")

## Plot 10: Si1300nm
Si1300nm_conc<-ggplot(data=allFCMBeads_LongSummary[allFCMBeads_LongSummary$variable=="Si1300nm"&allFCMBeads_LongSummary$FCM!="AriaIII_FL"&notCellStream,],
                      aes(x=FCM,y=value,fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  geom_errorbar(aes(ymax=value+sd,ymin=value-sd),size=0.8,width=0.25)+
  # Layout:
  labs(x="",y="Concentration\n[Events/L]",title = "1300 nm")+
  scale_x_discrete(limits=c("AriaIII_SSC","Apogee","ISXII"))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","AriaIII_SSC","ISXII"))+
  theme_classic()+th

# Saving plot as .eps
Si1300nm_conc_grob<-ggplotGrob(Si1300nm_conc)
Si1300nm_conc_grob$respect=T
ggsave(filename = "Si1300nm_conc.pdf",plot=Si1300nm_conc_grob,device = "pdf",height = 45, units = "mm")


## Plot 11: FACS Aria III LoQ
Data_AriaIIIBeads_LoQ<-allFCMBeads_LongSummary[allFCMBeads_LongSummary$FCM=="AriaIII_FL"|allFCMBeads_LongSummary$FCM=="AriaIII_SSC"&notCellStream,]
Data_AriaIIIBeads_LoQ<-Data_AriaIIIBeads_LoQ[-c(2,4:11,13),]

AriaIII_LoQ<-ggplot(data=Data_AriaIIIBeads_LoQ,
                      aes(x=variable,y=CV))+
  geom_hline(yintercept = 20,size=0.8,colour="Red",linetype="dashed")+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5, fill="#2E9FDF")+
  # Layout:
  labs(x="",y="CV [%]",title = "FACS Aria III")+
  scale_x_discrete(limits=c("Si100nm","Si180nm","Si240nm","Si300nm","Si590nm","Si880nm","Si1300nm","Ps110nm","Ps280nm","Ps500nm"),
                   labels=c("Si100 nm","Si180 nm","Si240 nm","Si300 nm","Si590 nm","Si880 nm","Si1300 nm","Ps110 nm","Ps280 nm","Ps500 nm"))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  theme_classic()+th+theme(axis.text.x = element_text(size=10,colour = "black",angle = 45,hjust = 1,vjust = 1))

# Saving plot as .eps
AriaIII_LoQ_grob<-ggplotGrob(AriaIII_LoQ)
AriaIII_LoQ_grob$respect=T
ggsave(filename = "AriaIII_LoQ.pdf",plot=AriaIII_LoQ_grob,device = "pdf",height = 80, units = "mm")


## Plot 12: Apogee LoQ
Apogee_LoQ<-ggplot(data=allFCMBeads_LongSummary[allFCMBeads_LongSummary$FCM=="Apogee",],
                    aes(x=variable,y=CV))+
  geom_hline(yintercept = 20,size=0.8,colour="Red",linetype="dashed")+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5, fill="#E7B800")+
  # Layout:
  labs(x="",y="CV [%]",title = "Apogee")+
  scale_x_discrete(limits=c("Si100nm","Si180nm","Si240nm","Si300nm","Si590nm","Si880nm","Si1300nm","Ps110nm","Ps280nm","Ps500nm"),
                   labels=c("Si100 nm","Si180 nm","Si240 nm","Si300 nm","Si590 nm","Si880 nm","Si1300 nm","Ps110 nm","Ps280 nm","Ps500 nm"))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  theme_classic()+th+theme(axis.text.x = element_text(size=10,colour = "black",angle = 45,hjust = 1,vjust = 1))

# Saving plot as .eps
Apogee_LoQ_grob<-ggplotGrob(Apogee_LoQ)
Apogee_LoQ_grob$respect=T
ggsave(filename = "Apogee_LoQ.pdf",plot=Apogee_LoQ_grob,device = "pdf",height = 80, units = "mm")


## Plot 13: ISXII LoQ
ISXII_LoQ<-ggplot(data=allFCMBeads_LongSummary[allFCMBeads_LongSummary$FCM=="ISXII",],
                   aes(x=variable,y=CV))+
  geom_hline(yintercept = 20,size=0.8,colour="Red",linetype="dashed")+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5, fill="#FC4E07")+
  # Layout:
  labs(x="",y="CV [%]",title = "ImageStream X Mark II")+
  scale_x_discrete(limits=c("Si100nm","Si180nm","Si240nm","Si300nm","Si590nm","Si880nm","Si1300nm","Ps110nm","Ps280nm","Ps500nm"),
                   labels=c("Si100 nm","Si180 nm","Si240 nm","Si300 nm","Si590 nm","Si880 nm","Si1300 nm","Ps110 nm","Ps280 nm","Ps500 nm"))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  theme_classic()+th+theme(axis.text.x = element_text(size=10,colour = "black",angle = 45,hjust = 1,vjust = 1))

# Saving plot as .eps
ISXII_LoQ_grob<-ggplotGrob(ISXII_LoQ)
ISXII_LoQ_grob$respect=T
ggsave(filename = "ISXII_LoQ.pdf",plot=ISXII_LoQ_grob,device = "pdf",height = 80, units = "mm")


## Plot 14: CellStream LoQ
CellStream_LoQ<-ggplot(data=allFCMBeads_LongSummary[allFCMBeads_LongSummary$FCM=="CellStream",],
                   aes(x=variable,y=CV))+
  geom_hline(yintercept = 20,size=0.8,colour="Red",linetype="dashed")+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5, fill="#00E796")+
  # Layout:
  labs(x="",y="CV [%]",title = "CellStream")+
  scale_x_discrete(limits=c("Si100nm","Si180nm","Si240nm","Si300nm","Si590nm","Si880nm","Si1300nm","Ps110nm","Ps280nm","Ps500nm"),
                   labels=c("Si100nm","Si180nm","Si240nm","Si300nm","Si590nm","Si880nm","Si1300nm","Ps110nm","Ps280nm","Ps500nm"))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  theme_classic()+th+theme(axis.text.x = element_text(size=10,colour = "black",angle = 45,hjust = 1,vjust = 1))

# Saving plot as .eps
CellStream_LoQ_grob<-ggplotGrob(CellStream_LoQ)
CellStream_LoQ_grob$respect=T
ggsave(filename = "CellStream_LoQ.pdf",plot=CellStream_LoQ_grob,device = "pdf",height = 80, units = "mm")
