###################################################################################################
## Title: EV quantification analysis script                                                      ##
## Project: Comparison Study                                                                     ##
## Version: 20190605                                                                             ##
## Author: Jaco Botha                                                                            ##
##                                                                                               ##
## Description:                                                                                  ##
## Script for analysing and plotting EV quantification data from three different flow cytome-    ##
## try platforms.                                                                                ##
###################################################################################################

#####
## Loading libraries for analysis and plotting.
#####

library(xlsx) ## for reading .xls and .xlsx files generated by FlowJo and IDEAS.
library(reshape2) ## for reshaping data from wide to long format.
library(ggplot2) ## for plotting data.
library(grid) ## for saving plots
library(extrafont) ## for using standard windows fonts

## Load fonts for plotting.
loadfonts(device = "win")
windowsFonts(Calibri = windowsFont("Calibri"))

#####
## Support function for summarising data.
#####

#+++++++++++++++++++++++++
# Function to calculate the mean and the standard deviation
# for each group
#+++++++++++++++++++++++++
# data : a data frame
# varname : the name of a column containing the variable
#to be summariezed
# groupnames : vector of column names to be used as
# grouping variables
data_summary <- function(data, varname, groupnames){
  require(plyr)
  summary_func <- function(x, col){
    c(mean = mean(x[[col]], na.rm=TRUE),
      sd = sd(x[[col]], na.rm=TRUE))
  }
  data_sum<-ddply(data, groupnames, .fun=summary_func,
                  varname)
  data_sum <- rename(data_sum, c("mean" = varname))
  return(data_sum)
}


setwd("F:/ComparisonStudy/Results/")

#####
## Part 1: Read data into memory.
#####

## Defines column classes.
classes<-c("character","numeric",rep("character",times=3),rep("numeric",times=13))

## Conventional FCM
cFCM_PPPData<-read.xlsx(file = "./20190531_FACSAriaIII_EVStatistics.xls", sheetIndex = 1, header = T,colClasses = classes)
colnames(cFCM_PPPData)[1]<-"ID"

# Plots TruCount data to confirm viability of approach to use median for PBS+Iso, PBS+Lab & PBS controls
plotTrucount<-ggplot(data=cFCM_PPPData[cFCM_PPPData$N_TruCount>1000&cFCM_PPPData$Type!="Detergent",],
                     aes(x=1:length(cFCM_PPPData$N_TruCount[cFCM_PPPData$N_TruCount>1000&cFCM_PPPData$Type!="Detergent"]),
                         y=N_TruCount))+
  geom_rect(aes(ymin=mean(cFCM_PPPData$N_TruCount[cFCM_PPPData$N_TruCount>1000&cFCM_PPPData$Type!="Detergent"])-sd(cFCM_PPPData$N_TruCount[cFCM_PPPData$N_TruCount>1000&cFCM_PPPData$Type!="Detergent"]),
                ymax=mean(cFCM_PPPData$N_TruCount[cFCM_PPPData$N_TruCount>1000&cFCM_PPPData$Type!="Detergent"])+sd(cFCM_PPPData$N_TruCount[cFCM_PPPData$N_TruCount>1000&cFCM_PPPData$Type!="Detergent"]),
                xmin=0,xmax=length(cFCM_PPPData$N_TruCount[cFCM_PPPData$N_TruCount>1000&cFCM_PPPData$Type!="Detergent"])+1),colour="grey40",fill="grey40",alpha=0.1)+
  geom_line(colour="cyan",size=.6)+
  geom_point(colour="black",size=1)+
  geom_hline(aes(yintercept=mean(cFCM_PPPData$N_TruCount[cFCM_PPPData$N_TruCount>1000&cFCM_PPPData$Type!="Detergent"])),colour="black",size=.5,linetype="dashed")+
  geom_hline(aes(yintercept=median(cFCM_PPPData$N_TruCount[cFCM_PPPData$N_TruCount>1000&cFCM_PPPData$Type!="Detergent"])),colour="red",size=.5,linetype="dashed")+
  # Layout:
  labs(x="Sample Number",y="Events",title = "TruCount Beads")+
  scale_y_continuous(expand = expand_scale(mult = c(.1, .1)))+
  scale_x_continuous(limits = c(0,length(cFCM_PPPData$N_TruCount[cFCM_PPPData$N_TruCount>1000&cFCM_PPPData$Type!="Detergent"])+1),
                     expand = expand_scale(mult = c(0, 0)))+
  theme_classic()+theme(axis.title = element_text(size=10,vjust=0),
                        axis.text = element_text(size=8,colour = "black"),
                        plot.title = element_text(size=12,face = "bold"),
                        strip.text = element_text(size=12,vjust=0,face = "bold"),
                        strip.background = element_blank(),
                        axis.ticks.x = element_blank(),
                        # text=element_text(family="Calibri"),
                        legend.position = "none")

plotTrucount_grob<-ggplotGrob(plotTrucount)
ggsave(filename = "plotTrucount_cFCM.pdf",plot=plotTrucount_grob,device = "pdf",height = 45, width = 90, units = "mm")

# Data imputation by replacing all N_TruCount values < 1000 to the median (due to TruCount not being included in PBS samples).
cFCM_PPPData_NonImputed<-cFCM_PPPData
cFCM_PPPData$N_TruCount[cFCM_PPPData$N_TruCount<1000]<-median(cFCM_PPPData$N_TruCount[cFCM_PPPData$N_TruCount>1000&cFCM_PPPData$Type!="Detergent"])

c<-11:14
n<-7:10
#Calculation of imputed concentrations
for(i in 1:4){
  cFCM_PPPData[,c[i]]<-(cFCM_PPPData[,n[i]]*17/cFCM_PPPData$N_TruCount)*(49500/425)
}


## High-resolution FCM
hFCM_PPPData<-read.xlsx(file = "./20190531_Apogee_EVStatistics.xls", sheetIndex = 1, header = T,colClasses = classes)
colnames(hFCM_PPPData)[1]<-"ID"

## Imaging flow cytometer I
iFCM_PPPData_temp<-read.table(file = "./20190605_ISXII_Samples.txt", header = T, sep = "\t", as.is = T,
                              colClasses = c("character", rep("numeric", times = 25)), dec = ",",
                              nrows = 80, skip = 3)[,1:25]

## Creating factors for data analysis for iFCM data set

# Date
iFCM_date<-NULL
CharVec_temp<-strsplit(iFCM_PPPData_temp[,1],"_")
for(i in 1:dim(iFCM_PPPData_temp)[1]){
  iFCM_date[i]<-CharVec_temp[[i]][1]
}

# FCM
iFCM_FCM<-rep("ISXII",times=80)

# Sample
iFCM_sample<-rep("PPP",times=80)
iFCM_sample[grep("PBS",iFCM_PPPData_temp[,1])]<-"PBS"

# Type
iFCM_type<-rep("Unlabelled",times=80)
iFCM_type[grep("Labelled",iFCM_PPPData_temp[,1])]<-"Labelled"
iFCM_type[grep("Unlabelled",iFCM_PPPData_temp[,1])]<-"Unlabelled"
iFCM_type[grep("Isotype",iFCM_PPPData_temp[,1])]<-"Isotype"
iFCM_type[grep("Detergent",iFCM_PPPData_temp[,1])]<-"Detergent"
iFCM_type[grep("DET",iFCM_PPPData_temp[,1])]<-"Detergent"

# Test
iFCM_Variables<-cbind(iFCM_PPPData_temp[,1],iFCM_date,iFCM_FCM,iFCM_sample,iFCM_type)

## Creating new data frames for iFCM data
iFCM_PPPData<-data.frame(ID = iFCM_PPPData_temp[,1], Date = iFCM_date, FCM = iFCM_FCM,
                         Sample = iFCM_sample, Type = iFCM_type, iFCM_PPPData_temp[,2:13])

iFCM_PPPData_singlet<-data.frame(ID = iFCM_PPPData_temp[,1], Date = iFCM_date, FCM = iFCM_FCM,
                                 Sample = iFCM_sample, Type = iFCM_type, iFCM_PPPData_temp[,14:25])

## Correction concentration to Ev/ul and dilution factor of 17
iFCM_PPPData[,10:13]<-(iFCM_PPPData[,10:13]*17)/1000
iFCM_PPPData_singlet[10:13]<-(iFCM_PPPData_singlet[10:13]*17)/1000

# Imaging flow cytometer II
iFCM2_PPPData<-read.xlsx(file = "./20190531_CellStream_EVStatistics.xls", sheetIndex = 1, header = T,colClasses = classes)[1:90,]
colnames(iFCM2_PPPData)[1]<-"ID"

## Creating combined data set for all FCMs
allFCM_PPPData<-rbind.data.frame(iFCM_PPPData[,1:17],hFCM_PPPData[,c(1:5,7:18)],cFCM_PPPData[,c(1:5,7:18)],
                                 iFCM2_PPPData[,c(1:5,7:18)],stringsAsFactors = T)
allFCM_PPPData[,2]<-c(iFCM_date,hFCM_PPPData$Date,cFCM_PPPData$Date,iFCM2_PPPData$Date)
write.xlsx(x=allFCM_PPPData,file="./allFCM_Samples.xlsx",col.names = T)

## Subsetting on PPP and Labelled
# Creating logical arguments
isPPP<-allFCM_PPPData$Sample=="PPP"
isLabelled<-allFCM_PPPData$Type=="Labelled"

# Subsetting
allFCM_PPPLabelled<-allFCM_PPPData[isPPP&isLabelled,]
write.xlsx(x=allFCM_PPPLabelled,file="./allFCM_Samples_Labelled.xlsx",col.names = T)
allFCM_PPPLabelled_Long<-melt(allFCM_PPPLabelled,id.vars = c("ID","Date","FCM","Sample","Type"))

## Creating within-day subset
# Logical arguments
isiFCMLongDay<-allFCM_PPPLabelled$Date=="20180927"
ishFCMLongDay<-allFCM_PPPLabelled$Date=="20180408"
iscFCMLongDay<-allFCM_PPPLabelled$Date=="20180320"

# Subsetting
allFCM_PPPLabelled_within<-allFCM_PPPLabelled[isiFCMLongDay|ishFCMLongDay|iscFCMLongDay,]

## creating between-day subset
# Logical arguments
allFCM_PPPLabelled_between<-allFCM_PPPLabelled[-c(which(isiFCMLongDay)[c(6:20,26:40)],which(ishFCMLongDay)[6:20],
                                                  which(iscFCMLongDay)[6:20],40:44),]

## Converting data frames to long format to facilitate statistical analysis and plotting
allFCM_PPPLabelled_within_Long<-melt(allFCM_PPPLabelled_within,id.vars = c("ID","Date","FCM","Sample","Type"))
allFCM_PPPLabelled_within_Long$value<-as.numeric(allFCM_PPPLabelled_within_Long$value)
allFCM_PPPLabelled_between_Long<-melt(allFCM_PPPLabelled_between,id.vars = c("ID","Date","FCM","Sample","Type"))
allFCM_PPPLabelled_between_Long$value<-as.numeric(allFCM_PPPLabelled_between_Long$value)


## Creating summarised data frames with mean and SD for each phenotype by FCM platform
allFCM_PPPLabelled_Summary<-data_summary(allFCM_PPPLabelled_Long,varname = "value",
                                         groupnames = c("FCM","variable"))
allFCM_PPPLabelled_within_Summary<-data_summary(allFCM_PPPLabelled_within_Long,varname = "value",
                                                groupnames = c("FCM","variable"))
allFCM_PPPLabelled_between_Summary<-data_summary(allFCM_PPPLabelled_between_Long,varname = "value",
                                                 groupnames = c("FCM","variable"))

allFCM_PPPLabelled_between_Summary_bydate_pre<-data_summary(allFCM_PPPLabelled_between_Long,varname = "value",
                                                 groupnames = c("FCM","variable","Date"))
allFCM_PPPLabelled_between_Summary_bydate<-data_summary(allFCM_PPPLabelled_between_Summary_bydate_pre,varname = "value",
                                                        groupnames = c("FCM","variable"))

# Calculating CV%
allFCM_PPPLabelled_Summary$CV<-allFCM_PPPLabelled_Summary$sd/allFCM_PPPLabelled_Summary$value*100
allFCM_PPPLabelled_within_Summary$CV<-allFCM_PPPLabelled_within_Summary$sd/allFCM_PPPLabelled_within_Summary$value*100
allFCM_PPPLabelled_between_Summary$CV<-allFCM_PPPLabelled_between_Summary$sd/allFCM_PPPLabelled_between_Summary$value*100
allFCM_PPPLabelled_between_Summary_bydate_pre$CV<-allFCM_PPPLabelled_between_Summary_bydate_pre$sd/allFCM_PPPLabelled_between_Summary_bydate_pre$value*100
allFCM_PPPLabelled_between_Summary_bydate$CV<-allFCM_PPPLabelled_between_Summary_bydate$sd/allFCM_PPPLabelled_between_Summary_bydate$value*100

## Creationg table for exporting day-to-day variability statistics
phenotypes<-c("C_PSPos","C_CD41Pos","C_CD36Pos","C_CD41Pos_CD36Pos")
allFCM_PPPLabelled_between_Summary_bydate_pre_superMelt<-melt(allFCM_PPPLabelled_between_Summary_bydate_pre[allFCM_PPPLabelled_between_Summary_bydate_pre$variable%in%phenotypes,],
                                                              id.vars = c("FCM","variable","Date"))

colnames(allFCM_PPPLabelled_between_Summary_bydate_pre_superMelt)[4]<-"Statistic"

## Fold differrences in global concentrations.
#PS+
fc_PSPos<-matrix(nrow=4,ncol=4)
for(i in 1:4){
  for (j in 1:4){
    fc_PSPos[i,j]<-allFCM_PPPLabelled_Summary[allFCM_PPPLabelled_Summary$variable=="C_PSPos",'value'][i]/allFCM_PPPLabelled_Summary[allFCM_PPPLabelled_Summary$variable=="C_PSPos",'value'][j]
  }
}
rownames(fc_PSPos)<-allFCM_PPPLabelled_Summary[allFCM_PPPLabelled_Summary$variable=="C_PSPos",'FCM']
colnames(fc_PSPos)<-allFCM_PPPLabelled_Summary[allFCM_PPPLabelled_Summary$variable=="C_PSPos",'FCM']

#PS+|CD41+
fc_CD41Pos<-matrix(nrow=4,ncol=4)
for(i in 1:4){
  for (j in 1:4){
    fc_CD41Pos[i,j]<-allFCM_PPPLabelled_Summary[allFCM_PPPLabelled_Summary$variable=="C_CD41Pos",'value'][i]/allFCM_PPPLabelled_Summary[allFCM_PPPLabelled_Summary$variable=="C_CD41Pos",'value'][j]
  }
}
rownames(fc_CD41Pos)<-allFCM_PPPLabelled_Summary[allFCM_PPPLabelled_Summary$variable=="C_CD41Pos",'FCM']
colnames(fc_CD41Pos)<-allFCM_PPPLabelled_Summary[allFCM_PPPLabelled_Summary$variable=="C_CD41Pos",'FCM']

#PS+|CD36+
fc_CD36Pos<-matrix(nrow=4,ncol=4)
for(i in 1:4){
  for (j in 1:4){
    fc_CD36Pos[i,j]<-allFCM_PPPLabelled_Summary[allFCM_PPPLabelled_Summary$variable=="C_CD36Pos",'value'][i]/allFCM_PPPLabelled_Summary[allFCM_PPPLabelled_Summary$variable=="C_CD36Pos",'value'][j]
  }
}
rownames(fc_CD36Pos)<-allFCM_PPPLabelled_Summary[allFCM_PPPLabelled_Summary$variable=="C_CD36Pos",'FCM']
colnames(fc_CD36Pos)<-allFCM_PPPLabelled_Summary[allFCM_PPPLabelled_Summary$variable=="C_CD36Pos",'FCM']

#PS+|CD41+
fc_CD41PosCD36Pos<-matrix(nrow=4,ncol=4)
for(i in 1:4){
  for (j in 1:4){
    fc_CD41PosCD36Pos[i,j]<-allFCM_PPPLabelled_Summary[allFCM_PPPLabelled_Summary$variable=="C_CD41Pos_CD36Pos",'value'][i]/allFCM_PPPLabelled_Summary[allFCM_PPPLabelled_Summary$variable=="C_CD41Pos_CD36Pos",'value'][j]
  }
}
rownames(fc_CD41PosCD36Pos)<-allFCM_PPPLabelled_Summary[allFCM_PPPLabelled_Summary$variable=="C_CD41Pos_CD36Pos",'FCM']
colnames(fc_CD41PosCD36Pos)<-allFCM_PPPLabelled_Summary[allFCM_PPPLabelled_Summary$variable=="C_CD41Pos_CD36Pos",'FCM']

#####
## Part 2: Statistical analysis of concentrations of different EV phenotypes between platforms.
#####
pval_EVConc<-list()

## PS+ EVs
pval_EVConc$PSPos<-pairwise.t.test(x = allFCM_PPPLabelled_Long$value[allFCM_PPPLabelled_Long$variable=="C_PSPos"],
                                   g = allFCM_PPPLabelled_Long$FCM[allFCM_PPPLabelled_Long$variable=="C_PSPos"],paired = F,
                                   p.adjust.method = "holm")

## CD41+ EVs
pval_EVConc$CD41Pos<-pairwise.t.test(x = allFCM_PPPLabelled_Long$value[allFCM_PPPLabelled_Long$variable=="C_CD41Pos"],
                                     g = allFCM_PPPLabelled_Long$FCM[allFCM_PPPLabelled_Long$variable=="C_CD41Pos"],paired = F,
                                     p.adjust.method = "holm")

## CD36+ EVs
pval_EVConc$CD36Pos<-pairwise.t.test(x = allFCM_PPPLabelled_Long$value[allFCM_PPPLabelled_Long$variable=="C_CD36Pos"],
                                     g = allFCM_PPPLabelled_Long$FCM[allFCM_PPPLabelled_Long$variable=="C_CD36Pos"],paired = F,
                                     p.adjust.method = "holm")

## CD41+ EVs
pval_EVConc$CD41PosCD36Pos<-pairwise.wilcox.test(x = allFCM_PPPLabelled_Long$value[allFCM_PPPLabelled_Long$variable=="C_CD41Pos_CD36Pos"],
                                            g = allFCM_PPPLabelled_Long$FCM[allFCM_PPPLabelled_Long$variable=="C_CD41Pos_CD36Pos"],paired = F,
                                            p.adjust.method = "holm")

#####
## Part 3: Plotting
#####

## Theme
th<-theme(axis.title = element_text(size=10,vjust=0),
          axis.text = element_text(size=8,colour = "black"),
          axis.text.x=element_blank(),
          plot.title = element_text(size=12,face = "bold"),
          strip.text = element_text(size=12,vjust=0,face = "bold"),
          strip.background = element_blank(),
          axis.ticks.x = element_blank(),
          # text=element_text(family="Calibri"),
          legend.position = "none")


## Colours for grouping FCM platforms.
fcmColours<-c("#E7B800", "#2E9FDF", "#FC4E07","#00E796")
notCellStream<-allFCM_PPPLabelled_within_Summary$FCM!="CellStream"


## Plot 1: PS Positive EVs - within-day
PSPos_within<-ggplot(data=allFCM_PPPLabelled_within_Summary[allFCM_PPPLabelled_within_Summary$variable=="C_PSPos"&notCellStream,],
                     aes(x=FCM,y=value/100000,fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  geom_errorbar(aes(ymax=(value+sd)/100000,ymin=(value-sd)/100000),size=0.8,width=0.25)+
  # Layout:
  labs(x="",y=expression(atop("Concentration",paste("[x ",10^5," Events/L]",sep=""))),title = "PS+")+
  scale_x_discrete(limits=c("FACSAriaIII","Apogee","ISXII"),
                   labels= c("","","",""))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","FACSAriaIII","ISXII"))+
  theme_classic()+th

## Saving plot as .pdf
PSPos_wit_grob<-ggplotGrob(PSPos_within)
PSPos_wit_grob$respect <- T
ggsave(filename = "PSPos_within_conc.pdf",plot=PSPos_wit_grob,device = "pdf",height = 45, units = "mm")


## Plot 2: PS Positive EVs - between-day
PSPos_between<-ggplot(data=allFCM_PPPLabelled_between_Summary[allFCM_PPPLabelled_between_Summary$variable=="C_PSPos"&notCellStream,],
                      aes(x=FCM,y=value/100000,fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  geom_errorbar(aes(ymax=(value+sd)/100000,ymin=(value-sd)/100000),size=0.8,width=0.25)+
  # Layout:
  labs(x="",y=expression(atop("Concentration",paste("[x ",10^5," Events/L]",sep=""))),title = "PS+")+
  scale_x_discrete(limits=c("FACSAriaIII","Apogee","ISXII"),
                   labels= c("","","",""))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","FACSAriaIII","ISXII"))+
  theme_classic()+th

## Saving plot as .pdf
PSPos_bet_grob<-ggplotGrob(PSPos_between)
PSPos_bet_grob$respect <- T
ggsave(filename = "PSPos_between_conc.pdf",plot=PSPos_bet_grob,device = "pdf",height = 45, units = "mm")


## Plot 3: CD41 Positive EVs - within-day
CD41Pos_within<-ggplot(data=allFCM_PPPLabelled_within_Summary[allFCM_PPPLabelled_within_Summary$variable=="C_CD41Pos"&notCellStream,],
                       aes(x=FCM,y=value/10000,fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  geom_errorbar(aes(ymax=(value+sd)/10000,ymin=(value-sd)/10000),size=0.8,width=0.25)+
  # Layout:
  labs(x="",y=expression(atop("Concentration",paste("[x ",10^4," Events/L]",sep=""))),title = "PS+|CD41+")+
  scale_x_discrete(limits=c("FACSAriaIII","Apogee","ISXII"),
                   labels= c("","","",""))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","FACSAriaIII","ISXII"))+
  theme_classic()+th

## Saving plot as .pdf
CD41Pos_wit_grob<-ggplotGrob(CD41Pos_within)
CD41Pos_wit_grob$respect <- T
ggsave(filename = "CD41Pos_within_conc.pdf",plot=CD41Pos_wit_grob,device = "pdf",height = 45, units = "mm")


## Plot 4: CD41 Positive EVs - between-day
CD41Pos_between<-ggplot(data=allFCM_PPPLabelled_between_Summary[allFCM_PPPLabelled_between_Summary$variable=="C_CD41Pos"&notCellStream,],
                        aes(x=FCM,y=value/10000,fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  geom_errorbar(aes(ymax=(value+sd)/10000,ymin=(value-sd)/10000),size=0.8,width=0.25)+
  # Layout:
  labs(x="",y=expression(atop("Concentration",paste("[x ",10^4," Events/L]",sep=""))),title = "PS+|CD41+")+
  scale_x_discrete(limits=c("FACSAriaIII","Apogee","ISXII"),
                   labels= c("","","",""))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","FACSAriaIII","ISXII"))+
  theme_classic()+th

## Saving plot as .pdf
CD41Pos_bet_grob<-ggplotGrob(CD41Pos_between)
CD41Pos_bet_grob$respect <- T
ggsave(filename = "CD41Pos_between_conc.pdf",plot=CD41Pos_bet_grob,device = "pdf",height = 45, units = "mm")


## Plot 5: CD36 Positive EVs - within-day
CD36Pos_within<-ggplot(data=allFCM_PPPLabelled_within_Summary[allFCM_PPPLabelled_within_Summary$variable=="C_CD36Pos"&notCellStream,],
                       aes(x=FCM,y=value/10000,fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  geom_errorbar(aes(ymax=(value+sd)/10000,ymin=(value-sd)/10000),size=0.8,width=0.25)+
  # Layout:
  labs(x="",y=expression(atop("Concentration",paste("[x ",10^4," Events/L]",sep=""))),title = "PS+|CD36+")+
  scale_x_discrete(limits=c("FACSAriaIII","Apogee","ISXII"),
                   labels= c("","","",""))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","FACSAriaIII","ISXII"))+
  theme_classic()+th

## Saving plot as .pdf
CD36Pos_wit_grob<-ggplotGrob(CD36Pos_within)
CD36Pos_wit_grob$respect <- T
ggsave(filename = "CD36Pos_within_conc.pdf",plot=CD36Pos_wit_grob,device = "pdf",height = 45, units = "mm")


## Plot 6: CD36 Positive EVs - between-day
CD36Pos_between<-ggplot(data=allFCM_PPPLabelled_between_Summary[allFCM_PPPLabelled_between_Summary$variable=="C_CD36Pos"&notCellStream,],
                        aes(x=FCM,y=value/10000,fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  geom_errorbar(aes(ymax=(value+sd)/10000,ymin=(value-sd)/10000),size=0.8,width=0.25)+
  # Layout:
  labs(x="",y=expression(atop("Concentration",paste("[x ",10^4," Events/L]",sep=""))),title = "PS+|CD36+")+
  scale_x_discrete(limits=c("FACSAriaIII","Apogee","ISXII"),
                   labels= c("","","",""))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","FACSAriaIII","ISXII"))+
  theme_classic()+th

## Saving plot as .pdf
CD36Pos_bet_grob<-ggplotGrob(CD36Pos_between)
CD36Pos_bet_grob$respect <- T
ggsave(filename = "CD36Pos_between_conc.pdf",plot=CD36Pos_bet_grob,device = "pdf",height = 45, units = "mm")


## Plot 7: CD41&CD36 Positive EVs - within-day
CD41CD36Pos_within<-ggplot(data=allFCM_PPPLabelled_within_Summary[allFCM_PPPLabelled_within_Summary$variable=="C_CD41Pos_CD36Pos"&notCellStream,],
                           aes(x=FCM,y=value/10000,fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  geom_errorbar(aes(ymax=(value+sd)/10000,ymin=(value-sd)/10000),size=0.8,width=0.25)+
  # Layout:
  labs(x="",y=expression(atop("Concentration",paste("[x ",10^4," Events/L]",sep=""))),title = "PS+|CD41+|CD36+")+
  scale_x_discrete(limits=c("FACSAriaIII","Apogee","ISXII"),
                   labels= c("","","",""))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","FACSAriaIII","ISXII"))+
  theme_classic()+th

## Saving plot as .pdf
CD41CD36Pos_wit_grob<-ggplotGrob(CD41CD36Pos_within)
CD41CD36Pos_wit_grob$respect <- T
ggsave(filename = "CD41CD36Pos_within_conc.pdf",plot=CD41CD36Pos_wit_grob,device = "pdf",height = 45, units = "mm")


## Plot 8: CD41&CD36 Positive EVs - between-day
CD41CD36Pos_between<-ggplot(data=allFCM_PPPLabelled_between_Summary[allFCM_PPPLabelled_between_Summary$variable=="C_CD41Pos_CD36Pos"&notCellStream,],
                            aes(x=FCM,y=value/10000,fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  geom_errorbar(aes(ymax=(value+sd)/10000,ymin=(value-sd)/10000),size=0.8,width=0.25)+
  # Layout:
  labs(x="",y=expression(atop("Concentration",paste("[x ",10^4," Events/L]",sep=""))),title = "PS+|CD41+|CD36+")+
  scale_x_discrete(limits=c("FACSAriaIII","Apogee","ISXII"),
                   labels= c("","","",""))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","FACSAriaIII","ISXII"))+
  theme_classic()+th

## Saving plot as .pdf
CD41CD36Pos_bet_grob<-ggplotGrob(CD41CD36Pos_between)
CD41CD36Pos_bet_grob$respect <- T
ggsave(filename = "CD41CD36Pos_between_conc.pdf",plot=CD41CD36Pos_bet_grob,device = "pdf",height = 45, units = "mm")



## Plot 9: PS Positive EVs - within-day variability
VarPSPos_within<-ggplot(data=allFCM_PPPLabelled_within_Summary[allFCM_PPPLabelled_within_Summary$variable=="C_PSPos"&notCellStream,],
                        aes(x=FCM,y=(sd*100/value),fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  # Layout:
  labs(x="",y="Variability\n[%]",title = "PS+")+
  scale_x_discrete(limits=c("FACSAriaIII","Apogee","ISXII"),
                   labels= c("","","",""))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","FACSAriaIII","ISXII"))+
  theme_classic()+th

## Saving plot as .pdf
VarPSPos_within_grob<-ggplotGrob(VarPSPos_within)
VarPSPos_within_grob$respect <- T
ggsave(filename = "VarPSPos_within_conc.pdf",plot=VarPSPos_within_grob,device = "pdf",height = 45, units = "mm")


## Plot 10: PS Positive EVs - between-day variability
VarPSPos_between<-ggplot(data=allFCM_PPPLabelled_between_Summary_bydate[allFCM_PPPLabelled_between_Summary_bydate$variable=="C_PSPos"&notCellStream,],
                         aes(x=FCM,y=(sd*100/value),fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  # Layout:
  labs(x="",y="Variability\n[%]",title = "PS+")+
  scale_x_discrete(limits=c("FACSAriaIII","Apogee","ISXII"),
                   labels= c("","","",""))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","FACSAriaIII","ISXII"))+
  theme_classic()+th

## Saving plot as .pdf
VarPSPos_between_grob<-ggplotGrob(VarPSPos_between)
VarPSPos_between_grob$respect <- T
ggsave(filename = "VarPSPos_between_conc.pdf",plot=VarPSPos_between_grob,device = "pdf",height = 45, units = "mm")

## Plot 10B: PS Positive EVs - global variability
VarPSPos_global<-ggplot(data=allFCM_PPPLabelled_Summary[allFCM_PPPLabelled_Summary$variable=="C_PSPos"&notCellStream,],
                         aes(x=FCM,y=(sd*100/value),fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  # Layout:
  labs(x="",y="Variability\n[%]",title = "PS+")+
  scale_x_discrete(limits=c("FACSAriaIII","Apogee","ISXII"),
                   labels= c("","","",""))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","FACSAriaIII","ISXII"))+
  theme_classic()+th

## Saving plot as .pdf
VarPSPos_global_grob<-ggplotGrob(VarPSPos_global)
VarPSPos_global_grob$respect <- T
ggsave(filename = "VarPSPos_global_conc.pdf",plot=VarPSPos_global_grob,device = "pdf",height = 45, units = "mm")


## Plot 11: CD41 Positive EVs - within-day variability
VarCD41Pos_within<-ggplot(data=allFCM_PPPLabelled_within_Summary[allFCM_PPPLabelled_within_Summary$variable=="C_CD41Pos"&notCellStream,],
                          aes(x=FCM,y=(sd*100/value),fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  # Layout:
  labs(x="",y="Variability\n[%]",title = "PS+|CD41+")+
  scale_x_discrete(limits=c("FACSAriaIII","Apogee","ISXII"),
                   labels= c("","","",""))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","FACSAriaIII","ISXII"))+
  theme_classic()+th

## Saving plot as .pdf
VarCD41Pos_within_grob<-ggplotGrob(VarCD41Pos_within)
VarCD41Pos_within_grob$respect <- T
ggsave(filename = "VarCD41Pos_within_conc.pdf",plot=VarCD41Pos_within_grob,device = "pdf",height = 45, units = "mm")


## Plot 12: CD41 Positive EVs - between-day variability
VarCD41Pos_between<-ggplot(data=allFCM_PPPLabelled_between_Summary_bydate[allFCM_PPPLabelled_between_Summary_bydate$variable=="C_CD41Pos"&notCellStream,],
                           aes(x=FCM,y=(sd*100/value),fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  # Layout:
  labs(x="",y="Variability\n[%]",title = "PS+|CD41+")+
  scale_x_discrete(limits=c("FACSAriaIII","Apogee","ISXII"),
                   labels= c("","","",""))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","FACSAriaIII","ISXII"))+
  theme_classic()+th

## Saving plot as .pdf
VarCD41Pos_between_grob<-ggplotGrob(VarCD41Pos_between)
VarCD41Pos_between_grob$respect <- T
ggsave(filename = "VarCD41Pos_between_conc.pdf",plot=VarCD41Pos_between_grob,device = "pdf",height = 45, units = "mm")

## Plot 12b: CD41 Positive EVs - between-day variability
VarCD41Pos_global<-ggplot(data=allFCM_PPPLabelled_Summary[allFCM_PPPLabelled_Summary$variable=="C_CD41Pos"&notCellStream,],
                           aes(x=FCM,y=(sd*100/value),fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  # Layout:
  labs(x="",y="Variability\n[%]",title = "PS+|CD41+")+
  scale_x_discrete(limits=c("FACSAriaIII","Apogee","ISXII"),
                   labels= c("","","",""))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","FACSAriaIII","ISXII"))+
  theme_classic()+th

## Saving plot as .pdf
VarCD41Pos_global_grob<-ggplotGrob(VarCD41Pos_global)
VarCD41Pos_global_grob$respect <- T
ggsave(filename = "VarCD41Pos_global_conc.pdf",plot=VarCD41Pos_global_grob,device = "pdf",height = 45, units = "mm")


## Plot 13: CD36 Positive EVs - within-day variability
VarCD36Pos_within<-ggplot(data=allFCM_PPPLabelled_within_Summary[allFCM_PPPLabelled_within_Summary$variable=="C_CD36Pos"&notCellStream,],
                          aes(x=FCM,y=(sd*100/value),fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  # Layout:
  labs(x="",y="Variability\n[%]",title = "PS+|CD36+")+
  scale_x_discrete(limits=c("FACSAriaIII","Apogee","ISXII"),
                   labels= c("","","",""))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","FACSAriaIII","ISXII"))+
  theme_classic()+th

## Saving plot as .pdf
VarCD36Pos_within_grob<-ggplotGrob(VarCD36Pos_within)
VarCD36Pos_within_grob$respect <- T
ggsave(filename = "VarCD36Pos_within_conc.pdf",plot=VarCD36Pos_within_grob,device = "pdf",height = 45, units = "mm")


## Plot 14: CD36 Positive EVs - between-day variability
VarCD36Pos_between<-ggplot(data=allFCM_PPPLabelled_between_Summary_bydate[allFCM_PPPLabelled_between_Summary_bydate$variable=="C_CD36Pos"&notCellStream,],
                           aes(x=FCM,y=(sd*100/value),fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  # Layout:
  labs(x="",y="Variability\n[%]",title = "PS+|CD36+")+
  scale_x_discrete(limits=c("FACSAriaIII","Apogee","ISXII"),
                   labels= c("","","",""))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","FACSAriaIII","ISXII"))+
  theme_classic()+th

## Saving plot as .pdf
VarCD36Pos_between_grob<-ggplotGrob(VarCD36Pos_between)
VarCD36Pos_between_grob$respect <- T
ggsave(filename = "VarCD36Pos_between_conc.pdf",plot=VarCD36Pos_between_grob,device = "pdf",height = 45, units = "mm")

## Plot 14B: CD36 Positive EVs - global variability
VarCD36Pos_global<-ggplot(data=allFCM_PPPLabelled_Summary[allFCM_PPPLabelled_Summary$variable=="C_CD36Pos"&notCellStream,],
                           aes(x=FCM,y=(sd*100/value),fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  # Layout:
  labs(x="",y="Variability\n[%]",title = "PS+|CD36+")+
  scale_x_discrete(limits=c("FACSAriaIII","Apogee","ISXII"),
                   labels= c("","","",""))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","FACSAriaIII","ISXII"))+
  theme_classic()+th

## Saving plot as .pdf
VarCD36Pos_global_grob<-ggplotGrob(VarCD36Pos_global)
VarCD36Pos_global_grob$respect <- T
ggsave(filename = "VarCD36Pos_global_conc.pdf",plot=VarCD36Pos_global_grob,device = "pdf",height = 45, units = "mm")


## Plot 15: CD41&CD36 Positive EVs - within-day variability
VarCD41CD36Pos_within<-ggplot(data=allFCM_PPPLabelled_within_Summary[allFCM_PPPLabelled_within_Summary$variable=="C_CD41Pos_CD36Pos"&notCellStream,],
                              aes(x=FCM,y=(sd*100/value),fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  # Layout:
  labs(x="",y="Variability\n[%]",title = "PS+|CD41+|CD36+")+
  scale_x_discrete(limits=c("FACSAriaIII","Apogee","ISXII"),
                   labels= c("","","",""))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","FACSAriaIII","ISXII"))+
  theme_classic()+th

## Saving plot as .pdf
VarCD41CD36Pos_within_grob<-ggplotGrob(VarCD41CD36Pos_within)
VarCD41CD36Pos_within_grob$respect <- T
ggsave(filename = "VarCD41CD36Pos_within_conc.pdf",plot=VarCD41CD36Pos_within_grob,device = "pdf",height = 45, units = "mm")


## Plot 16: CD41&CD36 Positive EVs - between-day variability
VarCD41CD36Pos_between<-ggplot(data=allFCM_PPPLabelled_between_Summary_bydate[allFCM_PPPLabelled_between_Summary_bydate$variable=="C_CD41Pos_CD36Pos"&notCellStream,],
                               aes(x=FCM,y=(sd*100/value),fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  # Layout:
  labs(x="",y="Variability\n[%]",title = "PS+|CD41+|CD36+")+
  scale_x_discrete(limits=c("FACSAriaIII","Apogee","ISXII"),
                   labels= c("","","",""))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","FACSAriaIII","ISXII"))+
  theme_classic()+th

## Saving plot as .pdf
VarCD41CD36Pos_between_grob<-ggplotGrob(VarCD41CD36Pos_between)
VarCD41CD36Pos_between_grob$respect <- T
ggsave(filename = "VarCD41CD36Pos_between_conc.pdf",plot=VarCD41CD36Pos_between_grob,device = "pdf",height = 45, units = "mm")

## Plot 16B: CD41&CD36 Positive EVs - global variability
VarCD41CD36Pos_global<-ggplot(data=allFCM_PPPLabelled_Summary[allFCM_PPPLabelled_Summary$variable=="C_CD41Pos_CD36Pos"&notCellStream,],
                               aes(x=FCM,y=(sd*100/value),fill=FCM))+
  geom_bar(stat="identity",color="black",position=position_dodge(),size=0.8,width=0.5)+
  # Layout:
  labs(x="",y="Variability\n[%]",title = "PS+|CD41+|CD36+")+
  scale_x_discrete(limits=c("FACSAriaIII","Apogee","ISXII"),
                   labels= c("","","",""))+
  scale_y_continuous(expand = expand_scale(mult = c(0, .1)))+
  scale_fill_manual(values=fcmColours,limits=c("Apogee","FACSAriaIII","ISXII"))+
  theme_classic()+th

## Saving plot as .pdf
VarCD41CD36Pos_global_grob<-ggplotGrob(VarCD41CD36Pos_global)
VarCD41CD36Pos_global_grob$respect <- T
ggsave(filename = "VarCD41CD36Pos_global_conc.pdf",plot=VarCD41CD36Pos_global_grob,device = "pdf",height = 45, units = "mm")
